@@ -25,11 +25,15 @@
 #include <KLocalizedString>
 #include <QDebug>
 
+#include <config-X11.h>
+
 //Includes are ordered this way because of #defines in Xorg's headers
 #include "xrecordkeyboardmonitor.h" // krazy:exclude=includes
 #include "xlibbackend.h" // krazy:exclude=includes
 #include "xlibnotifications.h" // krazy:exclude=includes
+#if HAVE_XORGLIBINPUT
 #include "libinputtouchpad.h"
+#endif
 #include "synapticstouchpad.h"
 #include "propertyinfo.h"
 
@@ -119,9 +123,14 @@ XlibTouchpad* XlibBackend::findTouchpad()
 
         Atom *atom = properties.data(), *atomEnd = properties.data() + nProperties;
         for (; atom != atomEnd; atom++) {
+#if HAVE_XORGLIBINPUT
             if (*atom == m_libinputIdentifierAtom.atom()) {
+                setMode(TouchpadInputBackendMode::XLibinput);
                 return new LibinputTouchpad(m_display.data(), info->id);
-            } else if (*atom == m_synapticsIdentifierAtom.atom()) {
+            }
+#endif
+            if (*atom == m_synapticsIdentifierAtom.atom()) {
+                setMode(TouchpadInputBackendMode::XSynaptics);
                 return new SynapticsTouchpad(m_display.data(), info->id);
             }
         }
@@ -144,6 +153,20 @@ bool XlibBackend::applyConfig(const QVariantHash &p)
     return success;
 }
 
+bool XlibBackend::applyConfig()
+{
+    if (!m_device) {
+        return false;
+    }
+
+    bool success = m_device->applyConfig();
+    if (!success) {
+        m_errorString = i18n("Cannot apply touchpad configuration");
+    }
+
+    return success;
+}
+
 bool XlibBackend::getConfig(QVariantHash &p)
 {
     if (!m_device) {
@@ -157,6 +180,41 @@ bool XlibBackend::getConfig(QVariantHash &p)
     return success;
 }
 
+bool XlibBackend::getConfig()
+{
+    if(!m_device) {
+        return false;
+    }
+
+    bool success = m_device->getConfig();
+    if (!success) {
+        m_errorString = i18n("Cannot read touchpad configuration");
+    }
+    return success;
+}
+
+bool XlibBackend::getDefaultConfig()
+{
+    if (!m_device) {
+        return false;
+    }
+
+    bool success = m_device->getDefaultConfig();
+    if (!success) {
+        m_errorString = i18n("Cannot read default touchpad configuration");
+    }
+    return success;
+}
+
+bool XlibBackend::isChangedConfig() const
+{
+    if (!m_device) {
+        return false;
+    }
+
+    return m_device->isChangedConfig();
+}
+
 void XlibBackend::setTouchpadEnabled(bool enable)
 {
     if (!m_device) {
@@ -295,6 +353,24 @@ QStringList XlibBackend::listMouses(const QStringList &blacklist)
     return list;
 }
 
+QVector<QObject *> XlibBackend::getDevices() const
+{
+    QVector<QObject*> touchpads;
+
+#if HAVE_XORGLIBINPUT
+    LibinputTouchpad* libinputtouchpad = dynamic_cast<LibinputTouchpad*> (m_device.data());
+    if ( libinputtouchpad) {
+        touchpads.push_back(libinputtouchpad);
+    }
+#endif
+
+    SynapticsTouchpad* synaptics = dynamic_cast<SynapticsTouchpad*> (m_device.data());
+    if (synaptics) {
+        touchpads.push_back(synaptics);
+    }
+    return touchpads;
+}
+
 void XlibBackend::watchForEvents(bool keyboard)
 {
     if (!m_notifications) {
